use bevy::prelude::*;

#[derive(Resource, Debug, PartialEq, Clone)]
pub struct GlobalState {
    pub cursor_position: Vec2,
    pub window_extent: Vec2,
    pub polygon_started: bool,
    pub view_2d: bool,
    pub extrusion_height: f32,

    pub offscreen_image

    camera_3d: Option<Entity>,
    camera_2d: Option<Entity>,
}

impl GlobalState {
    pub fn setup_2d_cam(&mut self, cmd: &mut Commands) {
        self.camera_2d = Some(cmd.spawn(Camera2dBundle::default()).id());
    }

    pub fn setup_3d_cam(&mut self, cmd: &mut Commands) {
        self.camera_3d = Some(
            cmd.spawn(Camera3dBundle {
                transform: Transform::from_xyz(200.0, -600.0, 600.0)
                    .looking_at((self.window_extent * 0.5).extend(0.0), Vec3::Z),
                ..default()
            })
            .id(),
        );
    }

    pub fn camera_2d(&self) -> Entity {
        self.camera_2d.unwrap()
    }

    pub fn camera_3d(&self) -> Entity {
        self.camera_3d.unwrap()
    }
}

impl Default for GlobalState {
    fn default() -> Self {
        Self {
            cursor_position: Vec2::default(),
            window_extent: Vec2::default(),
            polygon_started: false,
            view_2d: true,
            extrusion_height: 20.0,

            camera_3d: None,
            camera_2d: None,
        }
    }
}

#[derive()]
